/*
 * main implementation: use this 'C' sample to create your own application
 *
 */
#include "derivative.h" /* include peripheral declarations */
#include "FreeRTOS.h"
#include "task.h"

#define RED         (18)
#define RED_SHIFT   (1<<RED)
#define GREEN       (19)
#define GREEN_SHIFT (1<<GREEN)

#define RED_OFF      (GPIOB_PSOR = RED_SHIFT)
#define RED_ON       (GPIOB_PCOR = RED_SHIFT)
#define RED_TOGGLE   (GPIOB_PTOR = RED_SHIFT)
#define GREEN_OFF    (GPIOB_PSOR = GREEN_SHIFT)
#define GREEN_ON     (GPIOB_PCOR = GREEN_SHIFT)
#define GREEN_TOGGLE (GPIOB_PTOR = GREEN_SHIFT)

static void InitLED(void) {
  /* Turn on clock to PortB module */
  SIM_SCGC5 |= SIM_SCGC5_PORTB_MASK;

  /* Set the PTB18 pin multiplexer to GPIO mode */
  PORTB_PCR18 = PORT_PCR_MUX(1);
  /* Set the PTB19 pin multiplexer to GPIO mode */
  PORTB_PCR19 = PORT_PCR_MUX(1);

  /* Set the initial output state to high */
  GPIOB_PSOR |= RED_SHIFT | GREEN_SHIFT;

  /* Set the pins direction to output */
  GPIOB_PDDR |= RED_SHIFT | GREEN_SHIFT;
}

static portTASK_FUNCTION(REDTask, pvParameters) {
  (void)pvParameters; /* parameter not used */
  for(;;) {
    GREEN_OFF;
    RED_TOGGLE;
    vTaskDelay(500/portTICK_RATE_MS);
  }
}

void vApplicationIdleHook( void ) {
    GREEN_ON;    
}

int main(void) {
  InitLED();
  if (xTaskCreate(
        REDTask,              /* pointer to the task */
        (signed char *)"REDTask", /* task name for kernel awareness debugging */
        configMINIMAL_STACK_SIZE, /* task stack size */
        (void*)NULL,           /* optional task startup argument */
        (tskIDLE_PRIORITY +1), /* initial priority */
        (xTaskHandle*)NULL     /* optional task handle to create */
      ) != pdPASS) {
    /*lint -e527 */
    for(;;){}; /* error! probably out of memory */
    /*lint +e527 */
  }
  vTaskStartScheduler(); /* does not return */
	return 0;
}
