#include "derivative.h"
#include "freedom_gpio.h"

// Simple Delay
void delay(void) {
  int i;
  for (i = 0; i < 1000000; i++) {
  }
}

// delay(ms) -- Spin wait delay (in ms)
//              Note:  uses low power timer (LPTMR)
void delay_ms(unsigned int length_ms)
{
    SIM_SCGC5 |= SIM_SCGC5_LPTMR_MASK;  // Make sure clock is enabled
    LPTMR0_CSR = 0;                     // Reset LPTMR settings         
    LPTMR0_CMR = length_ms;             // Set compare value (in ms)

    // Use 1kHz LPO with no prescaler
    LPTMR0_PSR = LPTMR_PSR_PCS(1) | LPTMR_PSR_PBYP_MASK;
    
    // Start the timer and wait for it to reach the compare value
    LPTMR0_CSR = LPTMR_CSR_TEN_MASK;
    while (!(LPTMR0_CSR & LPTMR_CSR_TCF_MASK))
        ;
    
    LPTMR0_CSR = 0;                     // Turn off timer
}


int main(void) {
  /* disable COP */
  SIM_COPC = 0;

  /* enable clocks for PORTB and PORTD */
  SIM_SCGC5 |= SIM_SCGC5_PORTB_MASK;
  SIM_SCGC5 |= SIM_SCGC5_PORTD_MASK;
  
  // Init RGB LED (all off)
  gpio_init();
  
  while (1) {
    // red on
    LED1_ON;
    delay_ms(1000);
    // red off
    LED1_OFF;
    //green_on
    LED2_ON;
    delay_ms(1000);
    //green off
    LED2_OFF;
    //blue on
    LED3_ON;
    delay_ms(1000);
 	//blue off
	LED3_OFF;
	
	//All LEDs off, wait, turn all on, blink, blink, all off
    //red on, green on, blue on
	int u;
	int k;
	
	delay_ms(800);	
	
	for(u=0;u<6;u++) {
	  LED1_ON;
	  LED2_ON;
	  LED3_ON;
	  delay_ms(100);
	  LED1_OFF;
	  LED2_OFF;
	  LED3_OFF;
	  delay_ms(100);
	}   
    //wait
    delay_ms(800);	
	
	// Led circular red,green,blue
    for(k=0;k<5;k++) {
	  // red on
      LED1_ON;
      delay_ms(200);
      // red off
      LED1_OFF;
      //green_on
      LED2_ON;
      delay_ms(200);
      //green off
      LED2_OFF;
      //blue on
      LED3_ON;
      delay_ms(200);
	  //blue off
	  LED3_OFF;
	  delay_ms(200);
	}
	
	//wait
	LED1_OFF;
	LED2_OFF;
	LED3_OFF;
    delay_ms(1000);	
  }         
}





